function varargout = getsamps(varargin)
% GETSAMPS M-file for getsamps.fig
%      GETSAMPS, by itself, creates a new GETSAMPS or raises the existing
%      singleton*.
%
%      [SAMPLES, NAMES, ISAMPLED] = GETSAMPS returns the burn-removed samples info
%      SAMPLES, with column names NAMES as specified when running GETSAMPS
%
%      SAMPLES is just the burn-removed contents of the samples files.
%      NAMES is a cell array containing the column names
%      ISAMPLED is an array of the column numbers worth plotting
%
%      GETSAMPS('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in GETSAMPS.M with the given input arguments.
%
%      GETSAMPS('Property','Value',...) creates a new GETSAMPS or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before getsamps_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to getsamps_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help getsamps

% Last Modified by GUIDE v2.5 04-Oct-2004 16:11:41

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @getsamps_OpeningFcn, ...
                   'gui_OutputFcn',  @getsamps_OutputFcn, ...
                   'gui_LayoutFcn',  @getsamps_LayoutFcn, ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before getsamps is made visible.
function getsamps_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to getsamps (see VARARGIN)

% set default handles associated with reading in samples file
handles.sampsdir= '../chains/'; % default samples directory
handles.namesdir= './'; % default names directory
handles.namesfile= 'CMB.names'; % default names filename
handles.nburn= 1000; % default number to burn
handles.nthin=10; % default thinning factor
samplesfiles=''; % ??

fid=fopen('getsamps_prefs.mat');
if (fid>0)
    fclose(fid);
    htmp=load('getsamps_prefs'); % sampsdir namesdir namesfile nburn nthin filescell
    % NB. loading the above into handles wipes the handles struct !
    % is there a way to add elements to a struct from another struct?
    % ie. handles= concatstruct(handles,htmp) or something? 
    % maybe could write one?
    handles.sampsdir=htmp.sampsdir;
    handles.namesdir=htmp.namesdir;
    handles.namesfile=htmp.namesfile;
    handles.nburn=htmp.nburn;
    handles.nthin=htmp.nthin;
    samplesfiles=htmp.samplesfiles;
    usefiles=htmp.usefiles;
end
    
set(handles.NamesButton,'String',[handles.namesfile]);
set(handles.NoBurnEdit,'String',num2str(handles.nburn));
set(handles.NoThinEdit,'String',num2str(handles.nthin));
set(handles.SamplesFilesListbox,'String',samplesfiles);
if (exist('usefiles'))
    set(handles.SamplesFilesListbox,'Value',usefiles);
end

% set default output values 
handles.samples = -1; % the contents of the samples file (ie. nothing yet..)
handles.names = 'Not known yet'; % the names of the columns (dummy)
handles.isampled= -1; % the columns worth plotting
handles.cuts= []; % default cuts

% Update handles structure
guidata(hObject, handles);

%% bring up the file browser immediately - will definitely want it!
%AddSamplesFilesButton_Callback(hObject, eventdata, handles)
% can't do this here, it seems, as this confuses it..

% UIWAIT makes getsamps wait for user response (see UIRESUME)
% uiwait(handles.getsamps);
uiwait; % don't let it assign the output arguments until we've got them


% --- Outputs from this function are returned to the command line.
function varargout = getsamps_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
if (isempty(handles))
    varargout{1} = -1;
    varargout{2} = 'Not known yet';
    varargout{3} = -1;
    varargout{4}=-1;
    varargout{5}=-1;
else    
    varargout{1} = handles.samples;
    varargout{2} = handles.names;
    varargout{3} = handles.isampled;
    varargout{4} = handles.cuts;
    if sum(sum(handles.samples~=-1))
        varargout{5} = gcf;
    else
        varargout{5}=-1;
    end
end

    
% --- Executes on button press in AddSamplesFilesButton.
function AddSamplesFilesButton_Callback(hObject, eventdata, handles)
% hObject    handle to AddSamplesFilesButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

[file,path] = uigetfile([handles.sampsdir,'*.txt']);
if ~isequal(file, 0)
    %open(file);
    handles.sampsdir=path; % probs will want to use this next time too
    oldfiles=get(handles.SamplesFilesListbox,'String');
    newfiles=strvcat(oldfiles,[path,file]);
    tmp=size(newfiles);
    nfiles=tmp(1);
    if (nfiles>get(handles.SamplesFilesListbox,'Max'))
        set(handles.SamplesFilesListbox,'Max',nfiles+10); 
        % why not just increasing as reqd.
%        fprintf(1,'Error: need to increase Max for Listbox SamplesFileList')
    end
    set(handles.SamplesFilesListbox,'String',newfiles);
    % highlight the new entry as well as previously highlighted entries
    set(handles.SamplesFilesListbox,'Value',...
        [get(handles.SamplesFilesListbox,'Value') nfiles]);
end

% Update handles structure
guidata(hObject, handles);

% --- Executes during object creation, after setting all properties.
function SamplesFilesListbox_CreateFcn(hObject, eventdata, handles)
% hObject    handle to SamplesFilesListbox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: listbox controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end

% --- Executes on selection change in SamplesFilesListbox.
function SamplesFilesListbox_Callback(hObject, eventdata, handles)
% hObject    handle to SamplesFilesListbox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns SamplesFilesListbox contents as cell array
%        contents{get(hObject,'Value')} returns selected item from SamplesFilesListbox


% --- Executes on button press in NamesButton.
function NamesButton_Callback(hObject, eventdata, handles)
% hObject    handle to NamesButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

[file,path] = uigetfile([handles.namesdir,'*.names']);
if ~isequal(file, 0)
    handles.namesdir=path;
    handles.namesfile=file;
    set(handles.NamesButton,'String',[handles.namesfile]);
end

% Update handles structure
guidata(hObject, handles);

% --- Executes during object creation, after setting all properties.
function NoBurnEdit_CreateFcn(hObject, eventdata, handles)
% hObject    handle to NoBurnEdit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end

% --- Executes on changing number in NoBurnEdit box
function NoBurnEdit_Callback(hObject, eventdata, handles)
% do nothing

% --- Executes on button press in LoadButton.
function LoadButton_Callback(hObject, eventdata, handles)
% hObject    handle to LoadButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

handles.nburn=str2double(get(handles.NoBurnEdit,'String'));
handles.nthin=str2double(get(handles.NoThinEdit,'String'));
handles.filescell=cellstr(get(handles.SamplesFilesListbox,'String'));

% get rid of repetitions in 
% get(handles.SamplesFilesListbox,'Value')
% why does this happen? Surely we would never want it.
vals=get(handles.SamplesFilesListbox,'Value');
iin=1;
for i=2:length(vals)
    if ~(vals(i)==vals(i-1))
        iin=[iin i];
    end
end

goodfile=0;
while (goodfile~=1)
[handles.samples,handles.names]=readsampsf( ...
    handles.filescell(vals(iin)), ...
    [handles.namesdir,handles.namesfile],...
    handles.nburn,handles.nthin);
    if isempty(handles.samples)
        fprintf('ERROR: No samples were stored\n')
        return;
    end
    if (length(handles.samples)>100)
        goodfile=1;
    else
        fprintf(1,'ERROR: File contains less than 100 lines!\n')
        return
%        AddSamplesfile_Callback(hObject,eventdata,handles);
    end    
end

% find out which columns are sampled from and which are fixed
handles.isampled=find(min(handles.samples,[],2)-max(handles.samples,[],2));
% we don't want to include the second column
% (also will change meaning of request for first column)
tmp=find(handles.isampled>=3);
handles.isampled=[1 handles.isampled(tmp)'];
%handles.isampled=handles.isampled([1 3:length(handles.isampled)]);
% don't include any columns that don't have names
tmp=size(handles.names);
handles.isampled=handles.isampled(find(handles.isampled<=tmp(1)));

handles=setdefaultcuts(handles);
guidata(hObject,handles); % store the changes

% save the inputs to a file for next-time
% annoying.. I can't put bits of structures to save..
% how can I do the below (and corresponding read in..) better?
sampsdir=handles.sampsdir;
namesdir=handles.namesdir;
namesfile=handles.namesfile;
nburn=handles.nburn;
nthin=handles.nthin;
samplesfiles=get(handles.SamplesFilesListbox,'String');
usefiles=get(handles.SamplesFilesListbox,'Value');
save getsamps_prefs sampsdir namesdir namesfile nburn nthin samplesfiles usefiles

uiresume; % OK, can now assign the output arguments now we've finished


% --- Executes on key press over getsamps with no controls selected.
function getsamps_KeyPressFcn(hObject, eventdata, handles)
% hObject    handle to getsamps (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% if a button is pressed at any time within this window, just make this
% equivalent to ...

% hmm, what if this window isn't called getsamps ??

cchar=get(gcf,'CurrentCharacter');
fprintf(1,['currentchar=',cchar,'\n'])
if (cchar=='q')
    close(gcf)
elseif (cchar=='a')
    AddSamplesFilesButton_Callback(hObject, eventdata, handles)
elseif (cchar=='l')
    LoadButton_Callback(hObject, eventdata, handles)
end

% whatever character is pressed, load the data
% (would ideally like this to happen only if `return' is pressed..
%  but how to check for this character?)
%LoadButton_Callback(hObject, eventdata, handles)


% --- Executes on button press in RemovePush.
function RemovePush_Callback(hObject, eventdata, handles)
% hObject    handle to RemovePush (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

samplesfiles=get(handles.SamplesFilesListbox,'String');
tmp=size(samplesfiles);
nfiles=tmp(1);

% remove all the highlighted files from the list
removefiles=get(handles.SamplesFilesListbox,'Value');
usefiles=[];
for i=1:nfiles
    if (~sum(i==removefiles))
        usefiles=[usefiles i]
    end
end

set(handles.SamplesFilesListbox,'String',samplesfiles(usefiles,:))
set(handles.SamplesFilesListbox,'Value',1); % ? anything more sensible?


% --- Executes on button press in cancelbutton.
function cancelbutton_Callback(hObject, eventdata, handles)
% hObject    handle to cancelbutton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

close(gcf)


% -------------------------------------------------------------------
% --- Called by functions above, to set cuts to default values
% esp. after reading in new data
function handles=setdefaultcuts(handles);

% Cuts are stored in handles.cuts
% format is
% handles.cuts(1,i) is the type of cut for parameter handles.isampled(i)
%                   cut type = 1 is just a top hat range
% handles.cuts(2,i) is the first parameter for this cut type 
%                   for cut type = 1 this is the minimum of the range
% handles.cuts(3,i) is the second parameter for this cut type
%                   for cut type = 1 this is the maximum of the range
% handles.cuts(j,i) is the j-1 th parameter for this cut type..
%
% In this subroutine just set to the default, ie. no cuts
% which is equivalent to handles.cuts(1,i)=1
% handles.cuts(2,i) = minimum value of this parameter
% handles.cuts(3,i) = maximum value of this parameter
% Set this up now, to make it easier to modify them later.

sz=size(handles.samples);
for i=1:sz(1)
    handles.cuts(1,i)=1;
    handles.cuts(2,i)= min(handles.samples(i,:));
    handles.cuts(3,i)= max(handles.samples(i,:));
end




% --- Executes during object creation, after setting all properties.
function NoThinEdit_CreateFcn(hObject, eventdata, handles)
% hObject    handle to NoThinEdit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function NoThinEdit_Callback(hObject, eventdata, handles)
% hObject    handle to NoThinEdit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of NoThinEdit as text
%        str2double(get(hObject,'String')) returns contents of NoThinEdit as a double




% --- Creates and returns a handle to the GUI figure. 
function h1 = getsamps_LayoutFcn(policy)
% policy - create a new figure or use a singleton. 'new' or 'reuse'.

persistent hsingleton;
if strcmpi(policy, 'reuse') & ishandle(hsingleton)
    h1 = hsingleton;
    return;
end

appdata = [];
appdata.GUIDEOptions = struct(...
    'active_h', [], ...
    'taginfo', struct(...
    'figure', 2, ...
    'pushbutton', 7, ...
    'edit', 4, ...
    'text', 8, ...
    'listbox', 3), ...
    'override', 0, ...
    'release', 13, ...
    'resize', 'none', ...
    'accessibility', 'callback', ...
    'mfile', 1, ...
    'callbacks', 1, ...
    'singleton', 1, ...
    'syscolorfig', 1, ...
    'blocking', 0, ...
    'lastSavedFile', 'D:\home\sarah\work\joint\cosmomc\mscripts\getsamps.m');
appdata.lastValidTag = 'getsamps_devel';
appdata.GUIDELayoutEditor = [];

h1 = figure(...
'Units','characters',...
'PaperUnits',get(0,'defaultfigurePaperUnits'),...
'Color',[0.87843137254902 0.874509803921569 0.890196078431373],...
'Colormap',[0 0 0.5625;0 0 0.625;0 0 0.6875;0 0 0.75;0 0 0.8125;0 0 0.875;0 0 0.9375;0 0 1;0 0.0625 1;0 0.125 1;0 0.1875 1;0 0.25 1;0 0.3125 1;0 0.375 1;0 0.4375 1;0 0.5 1;0 0.5625 1;0 0.625 1;0 0.6875 1;0 0.75 1;0 0.8125 1;0 0.875 1;0 0.9375 1;0 1 1;0.0625 1 1;0.125 1 0.9375;0.1875 1 0.875;0.25 1 0.8125;0.3125 1 0.75;0.375 1 0.6875;0.4375 1 0.625;0.5 1 0.5625;0.5625 1 0.5;0.625 1 0.4375;0.6875 1 0.375;0.75 1 0.3125;0.8125 1 0.25;0.875 1 0.1875;0.9375 1 0.125;1 1 0.0625;1 1 0;1 0.9375 0;1 0.875 0;1 0.8125 0;1 0.75 0;1 0.6875 0;1 0.625 0;1 0.5625 0;1 0.5 0;1 0.4375 0;1 0.375 0;1 0.3125 0;1 0.25 0;1 0.1875 0;1 0.125 0;1 0.0625 0;1 0 0;0.9375 0 0;0.875 0 0;0.8125 0 0;0.75 0 0;0.6875 0 0;0.625 0 0;0.5625 0 0],...
'IntegerHandle','off',...
'InvertHardcopy',get(0,'defaultfigureInvertHardcopy'),...
'KeyPressFcn','getsamps(''getsamps_devel_KeyPressFcn'',gcbo,[],guidata(gcbo))',...
'MenuBar','none',...
'Name','Get Samples',...
'NumberTitle','off',...
'PaperPosition',get(0,'defaultfigurePaperPosition'),...
'PaperSize',[20.98404194812 29.67743169791],...
'PaperType',get(0,'defaultfigurePaperType'),...
'Position',[103.8 39.923076923077 100 21.5384615384615],...
'Renderer',get(0,'defaultfigureRenderer'),...
'RendererMode','manual',...
'Resize','off',...
'HandleVisibility','callback',...
'Tag','getsamps_devel',...
'UserData',[],...
'Behavior',get(0,'defaultfigureBehavior'),...
'Visible','on',...
'CreateFcn', {@local_CreateFcn, '', appdata} );

appdata = [];
appdata.lastValidTag = 'AddSamplesFilesButton';

h2 = uicontrol(...
'Parent',h1,...
'Units','characters',...
'Callback','getsamps(''AddSamplesFilesButton_Callback'',gcbo,[],guidata(gcbo))',...
'FontSize',12,...
'ListboxTop',0,...
'Position',[21.8 17.7692307692308 35.8 2.15384615384615],...
'String','Add Samples File to List',...
'TooltipString','Browse to find another samples file. Press `a'' to shortcut.',...
'Tag','AddSamplesFilesButton',...
'Behavior',get(0,'defaultuicontrolBehavior'),...
'CreateFcn', {@local_CreateFcn, '', appdata} );

appdata = [];
appdata.lastValidTag = 'NoBurnEdit';

h3 = uicontrol(...
'Parent',h1,...
'Units','characters',...
'BackgroundColor',[1 1 1],...
'Callback','getsamps(''NoBurnEdit_Callback'',gcbo,[],guidata(gcbo))',...
'FontSize',12,...
'ListboxTop',0,...
'Position',[53.8 1.46153846153846 8.2 1.61538461538462],...
'String','1000',...
'Style','edit',...
'TooltipString','This number of lines will be ignored from the beginning of the samples file. It is important to remove early samples due to burn-in. Click the `Load'' button after modifying this number.',...
'CreateFcn', {@local_CreateFcn, 'getsamps(''NoBurnEdit_CreateFcn'',gcbo,[],guidata(gcbo))', appdata} ,...
'Tag','NoBurnEdit',...
'Behavior',get(0,'defaultuicontrolBehavior'));

appdata = [];
appdata.lastValidTag = 'NoBurnText';

h4 = uicontrol(...
'Parent',h1,...
'Units','characters',...
'FontSize',10,...
'ForegroundColor',[0 0.250980392156863 0],...
'ListboxTop',0,...
'Position',[51.4 3.38461538461539 13.2 1.23076923076923],...
'String','No. to Burn',...
'Style','text',...
'TooltipString','Specifies the number of lines at the beginning of each files to ignore. This helps to remove burn-in.',...
'Clipping','off',...
'Tag','NoBurnText',...
'Behavior',get(0,'defaultuicontrolBehavior'),...
'CreateFcn', {@local_CreateFcn, '', appdata} );

appdata = [];
appdata.lastValidTag = 'LoadButton';

h5 = uicontrol(...
'Parent',h1,...
'Units','characters',...
'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588],...
'Callback','getsamps(''LoadButton_Callback'',gcbo,[],guidata(gcbo))',...
'FontSize',12,...
'ForegroundColor',[0 0.501960784313725 0],...
'ListboxTop',0,...
'Position',[81.8 1.38461538461538 12.2 2.46153846153846],...
'String','Load',...
'TooltipString','Press this button to read in the selected files. Press ''l'' to shortcut.',...
'Tag','LoadButton',...
'Behavior',get(0,'defaultuicontrolBehavior'),...
'CreateFcn', {@local_CreateFcn, '', appdata} );

appdata = [];
appdata.lastValidTag = 'ParameterNamesFileText';

h6 = uicontrol(...
'Parent',h1,...
'Units','characters',...
'FontSize',10,...
'ForegroundColor',[0 0.250980392156863 0],...
'ListboxTop',0,...
'Position',[5.8 3.38461538461539 26 1.23076923076923],...
'String','Parameter Names File',...
'Style','text',...
'Clipping','off',...
'Tag','ParameterNamesFileText',...
'Behavior',get(0,'defaultuicontrolBehavior'),...
'CreateFcn', {@local_CreateFcn, '', appdata} );

appdata = [];
appdata.lastValidTag = 'SamplesFilesListbox';

h7 = uicontrol(...
'Parent',h1,...
'Units','characters',...
'BackgroundColor',[1 1 1],...
'Callback','getsamps(''SamplesFilesListbox_Callback'',gcbo,[],guidata(gcbo))',...
'Max',10,...
'Position',[5.8 5.23076923076923 86.2 12.3846153846154],...
'Style','listbox',...
'Value',1,...
'CreateFcn', {@local_CreateFcn, 'getsamps(''SamplesFilesListbox_CreateFcn'',gcbo,[],guidata(gcbo))', appdata} ,...
'Tag','SamplesFilesListbox',...
'Behavior',get(0,'defaultuicontrolBehavior'));

appdata = [];
appdata.lastValidTag = 'SamplesFilesText';

h8 = uicontrol(...
'Parent',h1,...
'Units','characters',...
'FontSize',10,...
'ForegroundColor',[0 0.250980392156863 0],...
'ListboxTop',0,...
'Position',[1.8 17.9230769230769 16.6 1.23076923076923],...
'String','Samples Files',...
'Style','text',...
'TooltipString','List of samples files selected. Those highlighted will be opened.',...
'Tag','SamplesFilesText',...
'Behavior',get(0,'defaultuicontrolBehavior'),...
'CreateFcn', {@local_CreateFcn, '', appdata} );

appdata = [];
appdata.lastValidTag = 'NamesButton';

h9 = uicontrol(...
'Parent',h1,...
'Units','characters',...
'Callback','getsamps(''NamesButton_Callback'',gcbo,[],guidata(gcbo))',...
'FontSize',12,...
'ListboxTop',0,...
'Position',[5.8 1.23076923076923 42.2 1.76923076923077],...
'String','CMB.params',...
'TooltipString','Click to modify. Names of columns in the samples file.',...
'Tag','NamesButton',...
'Behavior',get(0,'defaultuicontrolBehavior'),...
'CreateFcn', {@local_CreateFcn, '', appdata} );

appdata = [];
appdata.lastValidTag = 'RemovePush';

h10 = uicontrol(...
'Parent',h1,...
'Units','characters',...
'Callback','getsamps(''RemovePush_Callback'',gcbo,[],guidata(gcbo))',...
'FontSize',12,...
'ListboxTop',0,...
'Position',[59.8 17.7692307692308 19.2 2.15384615384615],...
'String','Remove File',...
'TooltipString','Removes files from the below list.',...
'Tag','RemovePush',...
'Behavior',get(0,'defaultuicontrolBehavior'),...
'CreateFcn', {@local_CreateFcn, '', appdata} );

appdata = [];
appdata.lastValidTag = 'cancelbutton';

h11 = uicontrol(...
'Parent',h1,...
'Units','characters',...
'Callback','getsamps(''cancelbutton_Callback'',gcbo,[],guidata(gcbo))',...
'FontSize',12,...
'ListboxTop',0,...
'Position',[81.8 17.7692307692308 15.2 2.15384615384615],...
'String','Cancel',...
'TooltipString','Quit this file selection operation.',...
'Tag','cancelbutton',...
'Behavior',get(0,'defaultuicontrolBehavior'),...
'CreateFcn', {@local_CreateFcn, '', appdata} );

appdata = [];
appdata.lastValidTag = 'NoThinEdit';

h12 = uicontrol(...
'Parent',h1,...
'Units','characters',...
'BackgroundColor',[1 1 1],...
'Callback','getsamps(''NoThinEdit_Callback'',gcbo,[],guidata(gcbo))',...
'CData',[],...
'FontSize',12,...
'ListboxTop',0,...
'Position',[69.8 1.30769230769231 8.2 1.61538461538462],...
'String','10',...
'Style','edit',...
'TooltipString','Factor by which to thin.',...
'CreateFcn', {@local_CreateFcn, 'getsamps(''NoThinEdit_CreateFcn'',gcbo,[],guidata(gcbo))', appdata} ,...
'Tag','NoThinEdit',...
'UserData',[],...
'Behavior',get(0,'defaultuicontrolBehavior'));

appdata = [];
appdata.lastValidTag = 'NoThinText';

h13 = uicontrol(...
'Parent',h1,...
'Units','characters',...
'CData',[],...
'FontSize',10,...
'ForegroundColor',[0 0.250980392156863 0],...
'ListboxTop',0,...
'Position',[65.8 3.30769230769231 15 1.23076923076923],...
'String','Thin Factor',...
'Style','text',...
'Clipping','off',...
'Tag','NoThinText',...
'UserData',[],...
'Behavior',get(0,'defaultuicontrolBehavior'),...
'CreateFcn', {@local_CreateFcn, '', appdata} );


hsingleton = h1;


% --- Set application data first then calling the CreateFcn. 
function local_CreateFcn(hObject, eventdata, createfcn, appdata)

if ~isempty(appdata)
   names = fieldnames(appdata);
   for i=1:length(names)
       name = char(names(i));
       setappdata(hObject, name, getfield(appdata,name));
   end
end

if ~isempty(createfcn)
   eval(createfcn);
end


% --- Handles default GUIDE GUI creation and callback dispatch
function varargout = gui_mainfcn(gui_State, varargin)


%   GUI_MAINFCN provides these command line APIs for dealing with GUIs
%
%      GETSAMPS, by itself, creates a new GETSAMPS or raises the existing
%      singleton*.
%
%      H = GETSAMPS returns the handle to a new GETSAMPS or the handle to
%      the existing singleton*.
%
%      GETSAMPS('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in GETSAMPS.M with the given input arguments.
%
%      GETSAMPS('Property','Value',...) creates a new GETSAMPS or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before untitled_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to untitled_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".

%   Copyright 1984-2004 The MathWorks, Inc.
%   $Revision: 1.4.6.8 $ $Date: 2004/04/15 00:06:57 $

gui_StateFields =  {'gui_Name'
                    'gui_Singleton'
                    'gui_OpeningFcn'
                    'gui_OutputFcn'
                    'gui_LayoutFcn'
                    'gui_Callback'};
gui_Mfile = '';
for i=1:length(gui_StateFields)
    if ~isfield(gui_State, gui_StateFields{i})
        error('Could not find field %s in the gui_State struct in GUI M-file %s', gui_StateFields{i}, gui_Mfile);        
    elseif isequal(gui_StateFields{i}, 'gui_Name')
        gui_Mfile = [gui_State.(gui_StateFields{i}), '.m'];
    end
end

numargin = length(varargin);

if numargin == 0
    % GETSAMPS
    % create the GUI
    gui_Create = 1;
elseif isequal(ishandle(varargin{1}), 1) && ispc && iscom(varargin{1}) && isequal(varargin{1},gcbo)
    % GETSAMPS(ACTIVEX,...)    
    vin{1} = gui_State.gui_Name;
    vin{2} = [get(varargin{1}.Peer, 'Tag'), '_', varargin{end}];
    vin{3} = varargin{1};
    vin{4} = varargin{end-1};
    vin{5} = guidata(varargin{1}.Peer);
    feval(vin{:});
    return;
elseif ischar(varargin{1}) && numargin>1 && isequal(ishandle(varargin{2}), 1)
    % GETSAMPS('CALLBACK',hObject,eventData,handles,...)
    gui_Create = 0;
else
    % GETSAMPS(...)
    % create the GUI and hand varargin to the openingfcn
    gui_Create = 1;
end

if gui_Create == 0
    varargin{1} = gui_State.gui_Callback;
    if nargout
        [varargout{1:nargout}] = feval(varargin{:});
    else
        feval(varargin{:});
    end
else
    if gui_State.gui_Singleton
        gui_SingletonOpt = 'reuse';
    else
        gui_SingletonOpt = 'new';
    end
    
    % Open fig file with stored settings.  Note: This executes all component
    % specific CreateFunctions with an empty HANDLES structure.
    
    % Do feval on layout code in m-file if it exists
    if ~isempty(gui_State.gui_LayoutFcn)
        gui_hFigure = feval(gui_State.gui_LayoutFcn, gui_SingletonOpt);
        % openfig (called by local_openfig below) does this for guis without
        % the LayoutFcn. Be sure to do it here so guis show up on screen.
        movegui(gui_hFigure,'onscreen')
    else
        gui_hFigure = local_openfig(gui_State.gui_Name, gui_SingletonOpt);            
        % If the figure has InGUIInitialization it was not completely created
        % on the last pass.  Delete this handle and try again.
        if isappdata(gui_hFigure, 'InGUIInitialization')
            delete(gui_hFigure);
            gui_hFigure = local_openfig(gui_State.gui_Name, gui_SingletonOpt);            
        end
    end
    
    % Set flag to indicate starting GUI initialization
    setappdata(gui_hFigure,'InGUIInitialization',1);

    % Fetch GUIDE Application options
    gui_Options = getappdata(gui_hFigure,'GUIDEOptions');
    
    if ~isappdata(gui_hFigure,'GUIOnScreen')
        % Adjust background color
        if gui_Options.syscolorfig 
            set(gui_hFigure,'Color', get(0,'DefaultUicontrolBackgroundColor'));
        end

        % Generate HANDLES structure and store with GUIDATA
        guidata(gui_hFigure, guihandles(gui_hFigure));
    end
    
    % If user specified 'Visible','off' in p/v pairs, don't make the figure
    % visible.
    gui_MakeVisible = 1;
    for ind=1:2:length(varargin)
        if length(varargin) == ind
            break;
        end
        len1 = min(length('visible'),length(varargin{ind}));
        len2 = min(length('off'),length(varargin{ind+1}));
        if ischar(varargin{ind}) && ischar(varargin{ind+1}) && ...
                strncmpi(varargin{ind},'visible',len1) && len2 > 1
            if strncmpi(varargin{ind+1},'off',len2)
                gui_MakeVisible = 0;
            elseif strncmpi(varargin{ind+1},'on',len2)
                gui_MakeVisible = 1;
            end
        end
    end
    
    % Check for figure param value pairs
    for index=1:2:length(varargin)
        if length(varargin) == index
            break;
        end
        try set(gui_hFigure, varargin{index}, varargin{index+1}), catch break, end
    end

    % If handle visibility is set to 'callback', turn it on until finished
    % with OpeningFcn
    gui_HandleVisibility = get(gui_hFigure,'HandleVisibility');
    if strcmp(gui_HandleVisibility, 'callback')
        set(gui_hFigure,'HandleVisibility', 'on');
    end
    
    feval(gui_State.gui_OpeningFcn, gui_hFigure, [], guidata(gui_hFigure), varargin{:});
    
    if ishandle(gui_hFigure)
        % Update handle visibility
        set(gui_hFigure,'HandleVisibility', gui_HandleVisibility);
        
        % Make figure visible
        if gui_MakeVisible
            set(gui_hFigure, 'Visible', 'on')
            if gui_Options.singleton 
                setappdata(gui_hFigure,'GUIOnScreen', 1);
            end
        end

        % Done with GUI initialization
        rmappdata(gui_hFigure,'InGUIInitialization');
    end
    
    % If handle visibility is set to 'callback', turn it on until finished with
    % OutputFcn
    if ishandle(gui_hFigure)
        gui_HandleVisibility = get(gui_hFigure,'HandleVisibility');
        if strcmp(gui_HandleVisibility, 'callback')
            set(gui_hFigure,'HandleVisibility', 'on');
        end
        gui_Handles = guidata(gui_hFigure);
    else
        gui_Handles = [];
    end
    
    if nargout
        [varargout{1:nargout}] = feval(gui_State.gui_OutputFcn, gui_hFigure, [], gui_Handles);
    else
        feval(gui_State.gui_OutputFcn, gui_hFigure, [], gui_Handles);
    end
    
    if ishandle(gui_hFigure)
        set(gui_hFigure,'HandleVisibility', gui_HandleVisibility);
    end
end    

function gui_hFigure = local_openfig(name, singleton)

% openfig with three arguments was new from R13. Try to call that first, if
% failed, try the old openfig.
try 
    gui_hFigure = openfig(name, singleton, 'auto');
catch
    % OPENFIG did not accept 3rd input argument until R13,
    % toggle default figure visible to prevent the figure
    % from showing up too soon.
    gui_OldDefaultVisible = get(0,'defaultFigureVisible');
    set(0,'defaultFigureVisible','off');
    gui_hFigure = openfig(name, singleton);
    set(0,'defaultFigureVisible',gui_OldDefaultVisible);
end

